@@ -20,7 +20,7 @@ def upsacale(image,cvdnn_path):
     sr.readModel(cvdnn_path)
     sr.setPreferableBackend(cv2.dnn.DNN_BACKEND_CUDA)
     sr.setPreferableTarget(cv2.dnn.DNN_TARGET_CUDA)
-    sr.setModel("fsrcnn", 3)
+    sr.setModel("fsrcnn", 4)
     result = sr.upsample(image)
     return result
 
@@ -32,26 +32,28 @@ def inference(img_path,ocr,cvdnn_path):
             image= cv2.imread(img_path)
             img_path=upsacale(image,cvdnn_path)
             #img_path=predark(img_path)
+            cv2.imwrite("test.jpg",img_path)
             result = ocr.ocr(img_path, cls=True)
-            txts = [line[1][0] for line in result]
-            scores = [line[1][1] for line in result]
-            if len(txts)==0:          #no object detected
+            txts1 = [line[1][0] for line in result]
+            scores1 = [line[1][1] for line in result]
+            if len(txts1)==0:          #no object detected
                 return "999",float(0.0)  #object not found
             regex = '^[+-]?[0-9]+\.[0-9]$'
-            try:
-                for i in range(0,len(txts)):# most repeating txts
-                        if(re.search(regex, txts[i])): 
-                                if float(txts[i]) < 20.0 and float(txts[i]) >= 15.0:
-                                    txts.pop(i)
-                                    scores.pop(i)
-                                else:
+            txts=[]
+            scores=[]
+            for i in range(0,len(txts1)):# most repeating txts
+                try:
+                                if float(txts1[i]) > 20.0 or float(txts1[i]) < 15.0:
                                     pass
+                                else:
+                                    if re.search(regex, txts1[i]):
+                                        txts.append(txts1[i])
+                                        scores.append(scores1[i])
+                                    else:
+                                        pass
                                                 
-                        else:
-                            txts.pop(i)
-                            scores.pop(i)
-            except :
-                pass
+                except Exception as E:
+                    pass
             if len(txts)==0:
                    return "999",float(0.0) 
             try:
